/*------------------------------------*
	$CUSTOM SELECTS
*------------------------------------*/
.hasCustomSelect {
  width: 100%;
  z-index: 2;
}

.theme-select {
  position: relative;
  border: 1px solid #ddd;
  color: #555;
  height: 34px;
  line-height: 32px;
  padding: 0 45px 0 15px;
  width: 100%;
  z-index: 1;
}

.theme-select:after {
  font-family: 'Font Awesome 5 Free';
  content: '\f107';
  position: absolute;
  right: 0;
  top: 0;
  display: block;
  height: 32px;
  width: 32px;
  font-size: 11px;
  font-weight: 600;
  color: #929292;
  border-left: 1px solid #ddd;
  text-align: center;
}